"use strict";
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const assert = require("assert");
const lib_components_Box_Box_cjs = require("../Box/Box.cjs");
const lib_components_Text_Text_cjs = require("../Text/Text.cjs");
const lib_components_Columns_Columns_cjs = require("../Columns/Columns.cjs");
const lib_components_Column_Column_cjs = require("../Column/Column.cjs");
const lib_components_Inline_Inline_cjs = require("../Inline/Inline.cjs");
const lib_components_Disclosure_useDisclosure_cjs = require("../Disclosure/useDisclosure.cjs");
const lib_components_private_touchable_virtualTouchable_cjs = require("../private/touchable/virtualTouchable.cjs");
const lib_components_private_Overlay_Overlay_cjs = require("../private/Overlay/Overlay.cjs");
const lib_components_Accordion_AccordionContext_cjs = require("./AccordionContext.cjs");
const lib_components_private_buildDataAttributes_cjs = require("../private/buildDataAttributes.cjs");
const lib_components_Accordion_AccordionItem_css_cjs = require("./AccordionItem.css.cjs");
const lib_components_icons_IconChevron_IconChevron_cjs = require("../icons/IconChevron/IconChevron.cjs");
const lib_components_private_hideFocusRings_hideFocusRings_css_cjs = require("../private/hideFocusRings/hideFocusRings.css.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const itemSpaceForSize = {
  xsmall: "small",
  small: "medium",
  standard: "medium",
  large: "large"
};
const AccordionItem = ({
  id,
  label,
  children,
  badge,
  size: sizeProp,
  tone: toneProp,
  weight: weightProp,
  icon,
  data,
  ...restProps
}) => {
  const accordionContext = React.useContext(lib_components_Accordion_AccordionContext_cjs.AccordionContext);
  assert__default.default(
    !(accordionContext && sizeProp),
    "Size cannot be set on AccordionItem when inside Accordion. Size should be set on Accordion instead."
  );
  assert__default.default(
    !(accordionContext && toneProp),
    "Tone cannot be set on AccordionItem when inside Accordion. Tone should be set on Accordion instead."
  );
  assert__default.default(
    !(accordionContext && weightProp),
    "Weight cannot be set on AccordionItem when inside Accordion. Weight should be set on Accordion instead."
  );
  assert__default.default(
    toneProp === void 0 || lib_components_Accordion_AccordionContext_cjs.validTones.includes(toneProp),
    `The 'tone' prop should be one of the following: ${lib_components_Accordion_AccordionContext_cjs.validTones.map((x) => `"${x}"`).join(", ")}`
  );
  assert__default.default(
    // @ts-expect-error
    !badge || badge.type.__isBadge__,
    `AccordionItem badge prop can only be an instance of Badge. e.g. <AccordionItem badge={<Badge>New</Badge>}>`
  );
  assert__default.default(
    !badge || badge.props.bleedY === void 0,
    "Badge elements cannot set the 'bleedY' prop when passed to an AccordionItem component"
  );
  assert__default.default(
    !icon || icon.props.size === void 0 && icon.props.tone === void 0,
    "Icons cannot set the 'size' or 'tone' prop when passed to an AccordionItem component"
  );
  const size = (accordionContext == null ? void 0 : accordionContext.size) ?? sizeProp ?? "large";
  const tone = (accordionContext == null ? void 0 : accordionContext.tone) ?? toneProp ?? "neutral";
  const weight = (accordionContext == null ? void 0 : accordionContext.weight) ?? weightProp ?? "medium";
  const itemSpace = itemSpaceForSize[size] ?? "none";
  assert__default.default(
    typeof label === "undefined" || typeof label === "string",
    "Label must be a string"
  );
  const { expanded, buttonProps, contentProps } = lib_components_Disclosure_useDisclosure_cjs.useDisclosure({
    id,
    ...restProps.expanded !== void 0 ? {
      onToggle: restProps.onToggle,
      expanded: restProps.expanded
    } : {
      onToggle: restProps.onToggle
    }
  });
  return /* @__PURE__ */ jsxRuntime.jsxs(lib_components_Box_Box_cjs.Box, { ...lib_components_private_buildDataAttributes_cjs.buildDataAttributes({ data, validateRestProps: restProps }), children: [
    /* @__PURE__ */ jsxRuntime.jsxs(lib_components_Box_Box_cjs.Box, { position: "relative", display: "flex", children: [
      /* @__PURE__ */ jsxRuntime.jsx(
        lib_components_Box_Box_cjs.Box,
        {
          component: "button",
          type: "button",
          cursor: "pointer",
          className: [lib_components_Accordion_AccordionItem_css_cjs.button, lib_components_private_touchable_virtualTouchable_cjs.virtualTouchable()],
          outline: "none",
          width: "full",
          textAlign: "left",
          ...buttonProps,
          children: /* @__PURE__ */ jsxRuntime.jsx(lib_components_Box_Box_cjs.Box, { component: "span", position: "relative", children: /* @__PURE__ */ jsxRuntime.jsxs(lib_components_Columns_Columns_cjs.Columns, { component: "span", space: itemSpace, children: [
            /* @__PURE__ */ jsxRuntime.jsx(lib_components_Column_Column_cjs.Column, { children: /* @__PURE__ */ jsxRuntime.jsxs(lib_components_Inline_Inline_cjs.Inline, { component: "span", space: "small", alignY: "center", children: [
              /* @__PURE__ */ jsxRuntime.jsx(lib_components_Text_Text_cjs.Text, { size, weight, tone, icon, children: label }),
              badge ? React.cloneElement(badge, { bleedY: true }) : null
            ] }) }),
            /* @__PURE__ */ jsxRuntime.jsx(lib_components_Column_Column_cjs.Column, { width: "content", children: /* @__PURE__ */ jsxRuntime.jsx(
              lib_components_Text_Text_cjs.Text,
              {
                size,
                weight,
                tone: tone === "neutral" ? "secondary" : tone,
                children: /* @__PURE__ */ jsxRuntime.jsx(lib_components_icons_IconChevron_IconChevron_cjs.IconChevron, { direction: expanded ? "up" : "down" })
              }
            ) })
          ] }) })
        }
      ),
      /* @__PURE__ */ jsxRuntime.jsx(
        lib_components_private_Overlay_Overlay_cjs.Overlay,
        {
          boxShadow: "outlineFocus",
          borderRadius: "standard",
          transition: "fast",
          className: [lib_components_Accordion_AccordionItem_css_cjs.focusRing, lib_components_private_hideFocusRings_hideFocusRings_css_cjs.hideFocusRingsClassName]
        }
      )
    ] }),
    /* @__PURE__ */ jsxRuntime.jsx(
      lib_components_Box_Box_cjs.Box,
      {
        paddingTop: itemSpace,
        display: expanded ? "block" : "none",
        ...contentProps,
        children
      }
    )
  ] });
};
exports.AccordionItem = AccordionItem;
