"use strict";
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const assert = require("assert");
const lib_components_Box_Box_cjs = require("../Box/Box.cjs");
const lib_components_Text_Text_cjs = require("../Text/Text.cjs");
const lib_components_private_buildDataAttributes_cjs = require("../private/buildDataAttributes.cjs");
const lib_components_Bleed_Bleed_cjs = require("../Bleed/Bleed.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const validTones = [
  "promote",
  "info",
  "neutral",
  "positive",
  "caution",
  "critical"
];
const lightModeBackgroundForTone = {
  positive: "positiveLight",
  critical: "criticalLight",
  info: "infoLight",
  promote: "promoteLight",
  neutral: "neutralLight",
  caution: "cautionLight"
};
const verticalPadding = "xxsmall";
const stringifyChildren = (children) => {
  if (typeof children === "string") {
    return children;
  }
  if (typeof children === "number") {
    return children.toString();
  }
  return children.join("");
};
const Badge = React.forwardRef(
  ({
    tone = "info",
    weight = "regular",
    bleedY = false,
    title,
    children,
    id,
    data,
    tabIndex,
    "aria-describedby": ariaDescribedBy,
    ...restProps
  }, ref) => {
    assert__default.default(
      validTones.indexOf(tone) >= 0,
      `Badge tone of "${tone}" is not valid.`
    );
    assert__default.default(
      React.Children.toArray(children).every(
        (child) => ["string", "number"].includes(typeof child)
      ),
      "Badge may only contain strings or numbers"
    );
    const content = /* @__PURE__ */ jsxRuntime.jsx(
      lib_components_Box_Box_cjs.Box,
      {
        component: "span",
        display: "flex",
        cursor: "default",
        ...lib_components_private_buildDataAttributes_cjs.buildDataAttributes({ data, validateRestProps: restProps }),
        children: /* @__PURE__ */ jsxRuntime.jsx(
          lib_components_Box_Box_cjs.Box,
          {
            component: "span",
            id,
            ref,
            tabIndex,
            "aria-describedby": ariaDescribedBy,
            title: title ?? (!ariaDescribedBy ? stringifyChildren(children) : void 0),
            background: weight === "strong" ? tone : lightModeBackgroundForTone[tone],
            paddingY: verticalPadding,
            paddingX: "xsmall",
            borderRadius: "standard",
            overflow: "hidden",
            children: /* @__PURE__ */ jsxRuntime.jsx(lib_components_Text_Text_cjs.Text, { size: "xsmall", weight: "medium", maxLines: 1, children })
          }
        )
      }
    );
    return bleedY ? /* @__PURE__ */ jsxRuntime.jsx(lib_components_Bleed_Bleed_cjs.Bleed, { component: "span", vertical: verticalPadding, children: content }) : content;
  }
);
Badge.displayName = "Badge";
Badge.__isBadge__ = true;
exports.Badge = Badge;
