"use strict";
const jsxRuntime = require("react/jsx-runtime");
const assert = require("assert");
const dedent = require("dedent");
const React = require("react");
const lib_css_reset_resetTracker_cjs = require("../../css/reset/resetTracker.cjs");
const lib_components_private_hideFocusRings_useHideFocusRings_cjs = require("../private/hideFocusRings/useHideFocusRings.cjs");
const lib_components_BraidTestProvider_BraidTestProviderContext_cjs = require("../BraidTestProvider/BraidTestProviderContext.cjs");
const lib_components_BraidProvider_BreakpointContext_cjs = require("./BreakpointContext.cjs");
const lib_components_BraidProvider_BraidThemeContext_cjs = require("./BraidThemeContext.cjs");
const lib_css_atoms_sprinkles_css_cjs = require("../../css/atoms/sprinkles.css.cjs");
const lib_components_BraidProvider_VanillaThemeContainer_cjs = require("./VanillaThemeContainer.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const dedent__default = /* @__PURE__ */ _interopDefaultCompat(dedent);
if (process.env.NODE_ENV === "development") {
  lib_css_reset_resetTracker_cjs.ensureResetImported();
}
const makeLinkComponent = (render) => ({ __forwardRef__: React.forwardRef(render) });
const DefaultLinkComponent = makeLinkComponent((props, ref) => /* @__PURE__ */ jsxRuntime.jsx("a", { ref, ...props }));
const LinkComponentContext = React.createContext(DefaultLinkComponent);
const useLinkComponent = (ref) => {
  const linkComponent = React.useContext(LinkComponentContext);
  assert__default.default(
    !ref || "__forwardRef__" in linkComponent,
    dedent__default.default`
      You're passing a ref to a Braid link, but your app is providing a custom link component to 'BraidProvider' that doesn't appear to support refs.

      To fix this, you need to use Braid's 'makeLinkComponent' helper function when creating your custom link component. This ensures that refs are forwarded correctly, and allows us to silence this error message.

      For more information and an example implementation, check out the documentation for 'BraidProvider': https://seek-oss.github.io/braid-design-system/components/BraidProvider
    `
  );
  if ("__forwardRef__" in linkComponent) {
    return linkComponent.__forwardRef__;
  }
  return linkComponent;
};
const BraidProvider = ({
  theme,
  styleBody = true,
  linkComponent,
  children
}) => {
  const alreadyInBraidProvider = Boolean(React.useContext(lib_components_BraidProvider_BraidThemeContext_cjs.BraidThemeContext));
  const inTestProvider = React.useContext(lib_components_BraidTestProvider_BraidTestProviderContext_cjs.BraidTestProviderContext);
  const linkComponentFromContext = React.useContext(LinkComponentContext);
  lib_components_private_hideFocusRings_useHideFocusRings_cjs.useHideFocusRings(!(alreadyInBraidProvider || inTestProvider));
  assert__default.default(
    inTestProvider || typeof navigator === "undefined" || navigator.userAgent === void 0 || navigator.userAgent.indexOf("jsdom") === -1,
    `Rendering 'BraidProvider' in Jest is not supported as it expects a browser environment. Please switch to 'BraidTestProvider'. See the docs for more info: https://seek-oss.github.io/braid-design-system/components/BraidTestProvider`
  );
  return /* @__PURE__ */ jsxRuntime.jsxs(lib_components_BraidProvider_BraidThemeContext_cjs.BraidThemeContext.Provider, { value: theme, children: [
    styleBody ? /* @__PURE__ */ jsxRuntime.jsx("style", { type: "text/css", children: `
            html,body{margin:0;padding:0;background:${theme.background.lightMode}}
            html.${lib_css_atoms_sprinkles_css_cjs.darkMode},html.${lib_css_atoms_sprinkles_css_cjs.darkMode} body{color-scheme:dark;background:${theme.background.darkMode}}
          ` }) : null,
    /* @__PURE__ */ jsxRuntime.jsx(
      lib_components_BraidProvider_VanillaThemeContainer_cjs.VanillaThemeContainer,
      {
        theme: theme.vanillaTheme,
        setDefaultTextTones: !alreadyInBraidProvider,
        children: /* @__PURE__ */ jsxRuntime.jsx(
          LinkComponentContext.Provider,
          {
            value: linkComponent || linkComponentFromContext,
            children: alreadyInBraidProvider || inTestProvider ? children : /* @__PURE__ */ jsxRuntime.jsx(lib_components_BraidProvider_BreakpointContext_cjs.BreakpointProvider, { children })
          }
        )
      }
    )
  ] });
};
exports.BraidProvider = BraidProvider;
exports.makeLinkComponent = makeLinkComponent;
exports.useLinkComponent = useLinkComponent;
