"use strict";
const jsxRuntime = require("react/jsx-runtime");
const assert = require("assert");
const lib_utils_optimizeResponsiveArray_cjs = require("../../utils/optimizeResponsiveArray.cjs");
const lib_utils_resolveResponsiveRangeProps_cjs = require("../../utils/resolveResponsiveRangeProps.cjs");
const lib_components_Box_Box_cjs = require("../Box/Box.cjs");
const lib_components_BraidProvider_BraidThemeContext_cjs = require("../BraidProvider/BraidThemeContext.cjs");
const lib_components_private_buildDataAttributes_cjs = require("../private/buildDataAttributes.cjs");
const lib_components_private_Keyline_Keyline_cjs = require("../private/Keyline/Keyline.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const validCardComponents = [
  "div",
  "article",
  "aside",
  "details",
  "main",
  "section"
];
const borderRadius = "large";
const Card = ({
  children,
  component = "div",
  tone,
  data,
  height,
  ...restProps
}) => {
  assert__default.default(
    validCardComponents.includes(component),
    `Invalid Card component: '${component}'. Should be one of [${validCardComponents.map((c) => `'${c}'`).join(", ")}]`
  );
  const isLegacyTheme = lib_components_BraidProvider_BraidThemeContext_cjs.useBraidTheme().legacy;
  let resolvedRounding;
  if ("rounded" in restProps) {
    resolvedRounding = borderRadius;
  } else if ("roundedAbove" in restProps) {
    const [roundedOnMobile, roundedOnTablet, roundedOnDesktop, roundedOnWide] = lib_utils_resolveResponsiveRangeProps_cjs.resolveResponsiveRangeProps({ above: restProps.roundedAbove });
    resolvedRounding = lib_utils_optimizeResponsiveArray_cjs.optimizeResponsiveArray([
      roundedOnMobile ? borderRadius : "none",
      roundedOnTablet ? borderRadius : "none",
      roundedOnDesktop ? borderRadius : "none",
      roundedOnWide ? borderRadius : "none"
    ]);
  }
  const roundingForTheme = !isLegacyTheme ? borderRadius : resolvedRounding;
  return /* @__PURE__ */ jsxRuntime.jsxs(
    lib_components_Box_Box_cjs.Box,
    {
      component,
      position: "relative",
      background: "surface",
      padding: "gutter",
      borderRadius: roundingForTheme,
      boxShadow: !isLegacyTheme ? "borderNeutralLight" : void 0,
      height: height === "full" ? height : void 0,
      ...lib_components_private_buildDataAttributes_cjs.buildDataAttributes({ data, validateRestProps: restProps }),
      children: [
        tone ? /* @__PURE__ */ jsxRuntime.jsx(lib_components_private_Keyline_Keyline_cjs.Keyline, { tone, borderRadius: roundingForTheme }) : null,
        children
      ]
    }
  );
};
exports.Card = Card;
exports.validCardComponents = validCardComponents;
