"use strict";
const jsxRuntime = require("react/jsx-runtime");
const assert = require("assert");
const dedent = require("dedent");
const lib_components_Box_BackgroundContext_cjs = require("../Box/BackgroundContext.cjs");
const lib_hooks_useIcon_index_cjs = require("../../hooks/useIcon/index.cjs");
const lib_components_Box_Box_cjs = require("../Box/Box.cjs");
const lib_components_Text_Text_cjs = require("../Text/Text.cjs");
const lib_components_icons_IconStar_IconStarSvg_cjs = require("../icons/IconStar/IconStarSvg.cjs");
const lib_components_icons_IconStar_IconStarHalfSvg_cjs = require("../icons/IconStar/IconStarHalfSvg.cjs");
const lib_components_icons_IconStar_IconStarActiveSvg_cjs = require("../icons/IconStar/IconStarActiveSvg.cjs");
const lib_components_Rating_Rating_css_cjs = require("./Rating.css.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const dedent__default = /* @__PURE__ */ _interopDefaultCompat(dedent);
const getPercent = (rating, position) => Math.round(Math.min(Math.max(rating - position, 0), 1) * 100);
const RatingStar = ({ percent, ...restProps }) => {
  const currentBg = lib_components_Box_BackgroundContext_cjs.useBackground();
  const { className, ...iconProps } = lib_hooks_useIcon_index_cjs.useIcon(restProps);
  let component = lib_components_icons_IconStar_IconStarSvg_cjs.IconStarSvg;
  if (percent >= 25 && percent < 75) {
    component = lib_components_icons_IconStar_IconStarHalfSvg_cjs.IconStarHalfSvg;
  }
  if (percent >= 75) {
    component = lib_components_icons_IconStar_IconStarActiveSvg_cjs.IconStarActiveSvg;
  }
  return /* @__PURE__ */ jsxRuntime.jsx(
    lib_components_Box_Box_cjs.Box,
    {
      component,
      ...iconProps,
      className: [
        className,
        {
          [lib_components_Rating_Rating_css_cjs.lightModeStarColor]: currentBg.lightMode === "body" || currentBg.lightMode === "surface"
        },
        {
          [lib_components_Rating_Rating_css_cjs.darkModeStarColor]: currentBg.darkMode === "body" || currentBg.darkMode === "surface"
        }
      ]
    }
  );
};
const ratingArr = [...Array(5)];
const Rating = ({
  rating,
  size = "standard",
  weight,
  showTextRating,
  variant: variantProp,
  "aria-label": ariaLabel,
  data
}) => {
  assert__default.default(
    !rating || rating >= 0 && rating <= 5,
    "Rating must be between 0 and 5"
  );
  const variant = variantProp || "full";
  const resolvedVariant = showTextRating === false && !variantProp ? "starsOnly" : variant;
  if (process.env.NODE_ENV !== "production") {
    if (typeof showTextRating !== "undefined") {
      console.warn(
        dedent__default.default`
          The "showTextRating" prop has been deprecated and will be removed in a future version. Use \`variant="starsOnly"\` instead.
             <Rating
            %c-   showTextRating={false}
            %c+   variant="starsOnly"
             %c/>
        `,
        "color: red",
        "color: green",
        "color: inherit"
      );
    }
    if (typeof weight !== "undefined" && resolvedVariant === "starsOnly") {
      console.warn(
        dedent__default.default`
          The "weight" prop is not valid with the "starsOnly" variant as there is no visible text. Either remove the \`weight\` prop or choose an alternative \`variant\`.
             <Rating
            %c-  weight="strong"
            %c   variant="starsOnly"
             />
        `,
        "color: red",
        "color: inherit"
      );
    }
  }
  return /* @__PURE__ */ jsxRuntime.jsxs(lib_components_Text_Text_cjs.Text, { size, data, weight, children: [
    /* @__PURE__ */ jsxRuntime.jsx(
      lib_components_Box_Box_cjs.Box,
      {
        display: "inlineBlock",
        "aria-label": ariaLabel || `${rating.toFixed(1)} out of ${ratingArr.length}`,
        children: resolvedVariant === "minimal" ? /* @__PURE__ */ jsxRuntime.jsx(lib_components_Box_Box_cjs.Box, { display: "inlineBlock", "aria-hidden": true, children: /* @__PURE__ */ jsxRuntime.jsx(RatingStar, { percent: 100 }) }) : ratingArr.map((_, position) => /* @__PURE__ */ jsxRuntime.jsx(
          lib_components_Box_Box_cjs.Box,
          {
            display: "inlineBlock",
            "aria-hidden": true,
            className: {
              [lib_components_Rating_Rating_css_cjs.starSpacing]: position !== ratingArr.length - 1
            },
            children: /* @__PURE__ */ jsxRuntime.jsx(RatingStar, { percent: getPercent(rating, position) })
          },
          position
        ))
      }
    ),
    resolvedVariant !== "starsOnly" && /* @__PURE__ */ jsxRuntime.jsx(lib_components_Box_Box_cjs.Box, { component: "span", className: lib_components_Rating_Rating_css_cjs.textSpacing, "aria-hidden": true, children: rating.toFixed(1) })
  ] });
};
exports.Rating = Rating;
