"use strict";
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const assert = require("assert");
const lib_components_Box_Box_cjs = require("../Box/Box.cjs");
const lib_components_private_buildDataAttributes_cjs = require("../private/buildDataAttributes.cjs");
const lib_components_private_Overlay_Overlay_cjs = require("../private/Overlay/Overlay.cjs");
const lib_components_Tabs_TabsProvider_cjs = require("./TabsProvider.cjs");
const lib_components_Tabs_TabPanelsContext_cjs = require("./TabPanelsContext.cjs");
const lib_components_Tabs_Tabs_css_cjs = require("./Tabs.css.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const TabPanel = ({
  children,
  data,
  item,
  ...restProps
}) => {
  const tabsContext = React.useContext(lib_components_Tabs_TabsProvider_cjs.TabsContext);
  const tabPanelsContext = React.useContext(lib_components_Tabs_TabPanelsContext_cjs.TabPanelsContext);
  assert__default.default(
    tabsContext !== null,
    "A TabPanel must be rendered as a child of TabsProvider. See the documentation for correct usage: https://seek-oss.github.io/braid-design-system/components/Tabs"
  );
  if (!tabPanelsContext) {
    throw new Error("TabPanel rendered outside TabPanels");
  }
  if (!tabsContext) {
    throw new Error("TabPanel rendered outside TabsProvider");
  }
  const { a11y, selectedIndex, selectedItem } = tabsContext;
  const { panelIndex, renderInactive } = tabPanelsContext;
  const isSelected = selectedIndex > -1 ? panelIndex === selectedIndex : selectedItem === item;
  return /* @__PURE__ */ jsxRuntime.jsxs(
    lib_components_Box_Box_cjs.Box,
    {
      ...a11y.tabPanelProps({ panelIndex, isSelected }),
      display: isSelected ? void 0 : "none",
      position: "relative",
      outline: "none",
      className: lib_components_Tabs_Tabs_css_cjs.tabPanel,
      ...lib_components_private_buildDataAttributes_cjs.buildDataAttributes({ data, validateRestProps: restProps }),
      children: [
        isSelected || renderInactive ? children : void 0,
        /* @__PURE__ */ jsxRuntime.jsx(
          lib_components_private_Overlay_Overlay_cjs.Overlay,
          {
            zIndex: 1,
            boxShadow: "outlineFocus",
            borderRadius: "large",
            className: lib_components_Tabs_Tabs_css_cjs.tabPanelFocusRing,
            onlyVisibleForKeyboardNavigation: true
          }
        )
      ]
    }
  );
};
TabPanel.displayName = "TabPanel";
TabPanel.__isTabPanel__ = true;
exports.TabPanel = TabPanel;
