import { jsx } from "react/jsx-runtime";
import { useState, useEffect } from "react";
import { useFallbackId } from "../../playroom/utils.mjs";
import { TextDropdown as TextDropdown$1, parseSimpleToComplexOption } from "./TextDropdown.mjs";
const fallbackOptions = ["TextDropdown"];
function resolveValue(value, options) {
  if (typeof value === "undefined") {
    if (Array.isArray(options) && options.length > 0) {
      return parseSimpleToComplexOption(options[0]).value;
    }
    return fallbackOptions[0];
  }
  return value;
}
function resolveOptions(options) {
  return Array.isArray(options) && options.length > 0 ? options : fallbackOptions;
}
function TextDropdown({
  id,
  value,
  label,
  onChange,
  options = fallbackOptions,
  ...restProps
}) {
  const fallbackId = useFallbackId();
  const [internalValue, setInternalValue] = useState(
    resolveValue(value, options)
  );
  const [internalOptions, setInternalOptions] = useState(
    resolveOptions(options)
  );
  useEffect(() => {
    if (options !== internalOptions) {
      setInternalOptions(resolveOptions(options));
      setInternalValue(resolveValue(value, options));
    }
  }, [internalOptions, value, options]);
  return /* @__PURE__ */ jsx(
    TextDropdown$1,
    {
      id: id ?? fallbackId,
      label: label ?? "No label provided",
      value: internalValue,
      options: internalOptions,
      onChange: onChange ? onChange : setInternalValue,
      ...restProps
    }
  );
}
export {
  TextDropdown
};
