"use strict";
const jsxRuntime = require("react/jsx-runtime");
const React = require("react");
const FocusLock = require("react-focus-lock");
const lib_components_private_Modal_ariaHideOthers_cjs = require("./ariaHideOthers.cjs");
const lib_components_Box_Box_cjs = require("../../Box/Box.cjs");
const lib_components_BraidPortal_BraidPortal_cjs = require("../../BraidPortal/BraidPortal.cjs");
const lib_components_private_Modal_ModalExternalGutter_cjs = require("./ModalExternalGutter.cjs");
const lib_components_private_Modal_ModalContent_cjs = require("./ModalContent.cjs");
const lib_components_private_Modal_Modal_css_cjs = require("./Modal.css.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const FocusLock__default = /* @__PURE__ */ _interopDefaultCompat(FocusLock);
const AllowCloseContext = React.createContext(true);
const ModalPortal = ({ children }) => {
  const [modalElement, setElement] = React.useState(null);
  React.useEffect(() => {
    const modalContainerId = "braid-modal-container";
    let element = document.getElementById(modalContainerId);
    if (!element) {
      element = document.createElement("div");
      element.setAttribute("id", modalContainerId);
      element.setAttribute("class", lib_components_private_Modal_Modal_css_cjs.fixedStackingContext);
      document.body.appendChild(element);
    }
    setElement(element);
  }, []);
  if (!modalElement) {
    return null;
  }
  return /* @__PURE__ */ jsxRuntime.jsx(lib_components_BraidPortal_BraidPortal_cjs.BraidPortal, { container: modalElement, children });
};
const OPEN_MODAL = 1;
const CLOSE_MODAL = 2;
const ANIMATION_COMPLETE = 3;
const INITIAL = 1;
const OPEN = 2;
const OPENING = 3;
const CLOSED = 4;
const CLOSING = 5;
const reducer = (prevState, action) => {
  switch (action) {
    case OPEN_MODAL: {
      switch (prevState) {
        case INITIAL:
        case CLOSING:
        case CLOSED: {
          return OPENING;
        }
      }
    }
    case CLOSE_MODAL: {
      switch (prevState) {
        case OPEN:
        case OPENING: {
          return CLOSING;
        }
      }
    }
    case ANIMATION_COMPLETE: {
      switch (prevState) {
        case CLOSING: {
          return CLOSED;
        }
        case OPENING: {
          return OPEN;
        }
      }
    }
  }
  return prevState;
};
const ANIMATION_DURATION = 300;
const Modal = ({
  id,
  open,
  children,
  description,
  onClose,
  width,
  closeLabel,
  illustration,
  title,
  headingLevel,
  position,
  ...restProps
}) => {
  const [trapActive, setTrapActive] = React.useState(true);
  const [state, dispatch] = React.useReducer(reducer, INITIAL);
  const allowClose = React.useContext(AllowCloseContext);
  const shouldFocus = typeof document !== "undefined" && typeof document.hasFocus === "function" && document.hasFocus();
  const openRef = React.useRef(open);
  const modalRef = React.useRef(null);
  const headingRef = React.useRef(null);
  const closeHandlerRef = React.useRef(onClose);
  const initiateClose = () => {
    if (allowClose) {
      const result = closeHandlerRef.current(false);
      if (result === false) {
        return result;
      }
      if (openRef.current) {
        dispatch(CLOSE_MODAL);
      }
    }
  };
  React.useEffect(() => {
    openRef.current = open;
    dispatch(open ? OPEN_MODAL : CLOSE_MODAL);
  }, [open]);
  const closing = state === CLOSING;
  React.useEffect(() => {
    if (closing) {
      const timer = setTimeout(() => {
        dispatch(ANIMATION_COMPLETE);
      }, ANIMATION_DURATION);
      return () => clearTimeout(timer);
    }
  }, [closing]);
  const shouldAriaHideOthers = state === OPEN || state === CLOSING;
  React.useEffect(() => {
    if (shouldAriaHideOthers && modalRef.current) {
      return lib_components_private_Modal_ariaHideOthers_cjs.ariaHideOthers(modalRef.current, { delay: ANIMATION_DURATION });
    }
  }, [shouldAriaHideOthers]);
  React.useEffect(() => {
    if (typeof onClose === "function") {
      closeHandlerRef.current = onClose;
    }
  }, [onClose]);
  React.useEffect(() => {
    const event = trapActive ? "blur" : "focus";
    const handleEvent = () => setTrapActive(!trapActive);
    window.addEventListener(event, handleEvent);
    return () => {
      window.removeEventListener(event, handleEvent);
    };
  }, [trapActive]);
  return state === OPENING || state === OPEN || state === CLOSING ? /* @__PURE__ */ jsxRuntime.jsx(ModalPortal, { children: /* @__PURE__ */ jsxRuntime.jsxs(
    FocusLock__default.default,
    {
      className: lib_components_private_Modal_Modal_css_cjs.resetStackingContext,
      disabled: !trapActive,
      autoFocus: false,
      onActivation: () => {
        if (state === OPEN) {
          return;
        }
        if (headingRef.current && shouldFocus) {
          headingRef.current.focus();
        }
        dispatch(ANIMATION_COMPLETE);
      },
      returnFocus: true,
      children: [
        /* @__PURE__ */ jsxRuntime.jsx(
          lib_components_Box_Box_cjs.Box,
          {
            onClick: state === OPEN ? initiateClose : void 0,
            position: "fixed",
            inset: 0,
            zIndex: "modalBackdrop",
            transition: position === "center" ? "fast" : void 0,
            opacity: state !== OPEN ? 0 : void 0,
            pointerEvents: state === CLOSING ? "none" : void 0,
            className: [
              lib_components_private_Modal_Modal_css_cjs.backdrop,
              position === "left" || position === "right" && lib_components_private_Modal_Modal_css_cjs.horiztontalTransition
            ]
          }
        ),
        /* @__PURE__ */ jsxRuntime.jsx(
          lib_components_Box_Box_cjs.Box,
          {
            position: "fixed",
            inset: 0,
            zIndex: "modal",
            pointerEvents: "none",
            transition: "fast",
            opacity: state !== OPEN ? 0 : void 0,
            paddingLeft: position === "right" ? ["none", "xlarge"] : void 0,
            paddingRight: position === "left" ? ["none", "xlarge"] : void 0,
            padding: position === "center" ? lib_components_private_Modal_ModalExternalGutter_cjs.externalGutter : void 0,
            className: [
              lib_components_private_Modal_Modal_css_cjs.modalContainer,
              (position === "left" || position === "right") && lib_components_private_Modal_Modal_css_cjs.horiztontalTransition,
              state === OPENING && lib_components_private_Modal_Modal_css_cjs.entrance[position],
              state === CLOSING && position in lib_components_private_Modal_Modal_css_cjs.exit && lib_components_private_Modal_Modal_css_cjs.exit[position]
            ],
            children: /* @__PURE__ */ jsxRuntime.jsx(
              lib_components_private_Modal_ModalContent_cjs.ModalContent,
              {
                id,
                description,
                onClose: initiateClose,
                width,
                closeLabel,
                illustration,
                title,
                headingLevel,
                headingRef,
                modalRef,
                position,
                scrollLock: !(state === CLOSING),
                ...restProps,
                children
              }
            )
          }
        )
      ]
    }
  ) }) : null;
};
exports.AllowCloseContext = AllowCloseContext;
exports.Modal = Modal;
