"use strict";
const React = require("react");
const useTimeout = ({ onTimeout, duration }) => {
  const [activated, setActivated] = React.useState(true);
  const timeoutRef = React.useRef();
  const stopTimeout = React.useCallback(() => {
    window.clearTimeout(timeoutRef.current);
    setActivated(false);
  }, []);
  React.useEffect(() => {
    if (activated) {
      timeoutRef.current = window.setTimeout(() => {
        onTimeout();
      }, duration);
      return () => {
        stopTimeout();
      };
    }
  }, [onTimeout, activated, duration, stopTimeout]);
  const startTimeout = React.useCallback(() => {
    setActivated(true);
  }, []);
  return {
    stopTimeout,
    startTimeout
  };
};
exports.useTimeout = useTimeout;
