"use strict";
const React = require("react");
const assert = require("assert");
const clsx = require("clsx");
const lib_components_Text_TextContext_cjs = require("../../components/Text/TextContext.cjs");
const lib_components_Heading_HeadingContext_cjs = require("../../components/Heading/HeadingContext.cjs");
const lib_css_lineHeightContainer_css_cjs = require("../../css/lineHeightContainer.css.cjs");
const lib_components_private_buildDataAttributes_cjs = require("../../components/private/buildDataAttributes.cjs");
const lib_components_icons_IconRenderer_cjs = require("../../components/icons/IconRenderer.cjs");
const lib_css_atoms_atoms_cjs = require("../../css/atoms/atoms.cjs");
const lib_css_typography_css_cjs = require("../../css/typography.css.cjs");
const lib_hooks_useIcon_icon_css_cjs = require("./icon.css.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const assert__default = /* @__PURE__ */ _interopDefaultCompat(assert);
const clsx__default = /* @__PURE__ */ _interopDefaultCompat(clsx);
const iconSize = ({
  size = "standard",
  crop = false
} = {}) => clsx__default.default(lib_hooks_useIcon_icon_css_cjs.size, lib_css_typography_css_cjs.textSizeUntrimmed[size], {
  [lib_hooks_useIcon_icon_css_cjs.cropToTextSize]: crop
});
const iconContainerSize = (size = "standard") => clsx__default.default(lib_hooks_useIcon_icon_css_cjs.blockWidths[size], lib_css_lineHeightContainer_css_cjs.lineHeightContainer[size]);
const defaultVerticalCorrection = {
  uppercase: "none",
  lowercase: "none"
};
const useIcon = ({ size, tone, alignY, data, title, titleId, ...restProps }, { verticalCorrection = defaultVerticalCorrection } = {}) => {
  const textContext = React.useContext(lib_components_Text_TextContext_cjs.TextContext);
  const headingContext = React.useContext(lib_components_Heading_HeadingContext_cjs.HeadingContext);
  const resolvedTone = lib_css_typography_css_cjs.tone[tone || (textContext == null ? void 0 : textContext.tone) || "neutral"];
  const toneClass = tone || !headingContext && !(textContext == null ? void 0 : textContext.tone) ? resolvedTone : void 0;
  const isInline = Boolean(textContext || headingContext);
  const a11yProps = title ? { title, titleId, role: "img" } : { "aria-hidden": true };
  assert__default.default(
    !(size && isInline),
    `Specifying a custom \`size\` for an \`Icon\` inside the context of a \`<${textContext ? "Text" : "Heading"}>\` component is invalid. See the documentation for correct usage: https://seek-oss.github.io/braid-design-system/components/${textContext ? "Text" : "Heading"}`
  );
  assert__default.default(
    !(alignY && !isInline),
    `Specifying \`alignY\` for an \`Icon\` outside of a text component is invalid.`
  );
  if (size === "fill") {
    return {
      width: "full",
      height: "full",
      display: "block",
      className: toneClass,
      ...lib_components_private_buildDataAttributes_cjs.buildDataAttributes({ data, validateRestProps: restProps }),
      ...a11yProps
    };
  }
  return {
    className: [
      toneClass,
      isInline ? [
        lib_components_icons_IconRenderer_cjs.iconInlineSize({
          alignY: alignY || "uppercase",
          verticalCorrection: verticalCorrection[alignY || "uppercase"]
        })
      ] : [
        lib_css_atoms_atoms_cjs.atoms({
          display: "block"
        }),
        iconContainerSize(size)
      ]
    ],
    ...lib_components_private_buildDataAttributes_cjs.buildDataAttributes({ data, validateRestProps: restProps }),
    ...a11yProps
  };
};
exports.iconContainerSize = iconContainerSize;
exports.iconSize = iconSize;
exports.useIcon = useIcon;
