"use strict";
const appleSystemMetrics = require("@capsizecss/metrics/appleSystem");
const polished = require("polished");
const lib_color_palette_cjs = require("../../color/palette.cjs");
const lib_themes_tokenType_cjs = require("../tokenType.cjs");
const _interopDefaultCompat = (e) => e && typeof e === "object" && "default" in e ? e : { default: e };
const appleSystemMetrics__default = /* @__PURE__ */ _interopDefaultCompat(appleSystemMetrics);
const brandAccent = lib_color_palette_cjs.palette.grey["900"];
const formAccent = lib_color_palette_cjs.palette.indigo["600"];
const focus = polished.rgba("#1e90ff", 0.7);
const black = lib_color_palette_cjs.palette.grey["700"];
const white = "#fff";
const link = lib_color_palette_cjs.palette.indigo["600"];
const linkVisited = "DarkViolet";
const secondary = lib_color_palette_cjs.palette.grey["500"];
const tokens = {
  name: "docs",
  displayName: "Docs",
  legacy: false,
  typography: {
    fontFamily: '-apple-system, BlinkMacSystemFont, Roboto, "Segoe UI", Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
    webFont: null,
    fontMetrics: lib_themes_tokenType_cjs.extractFontMetricsForTheme(appleSystemMetrics__default.default),
    fontWeight: {
      regular: 400,
      medium: 500,
      strong: 700
    },
    heading: {
      weight: {
        weak: "regular",
        regular: "strong"
      },
      level: {
        "1": {
          mobile: {
            fontSize: 32,
            rows: 10
          },
          tablet: {
            fontSize: 52,
            rows: 15
          }
        },
        "2": {
          mobile: {
            fontSize: 28,
            rows: 9
          },
          tablet: {
            fontSize: 38,
            rows: 13
          }
        },
        "3": {
          mobile: {
            fontSize: 22,
            rows: 8
          },
          tablet: {
            fontSize: 22,
            rows: 8
          }
        },
        "4": {
          mobile: {
            fontSize: 18,
            rows: 8
          },
          tablet: {
            fontSize: 18,
            rows: 8
          }
        }
      }
    },
    text: {
      xsmall: {
        mobile: {
          fontSize: 14,
          rows: 6
        },
        tablet: {
          fontSize: 14,
          rows: 6
        }
      },
      small: {
        mobile: {
          fontSize: 16,
          rows: 6
        },
        tablet: {
          fontSize: 16,
          rows: 6
        }
      },
      standard: {
        mobile: {
          fontSize: 18,
          rows: 8
        },
        tablet: {
          fontSize: 18,
          rows: 8
        }
      },
      large: {
        mobile: {
          fontSize: 22,
          rows: 9
        },
        tablet: {
          fontSize: 22,
          rows: 9
        }
      }
    }
  },
  contentWidth: {
    xsmall: 400,
    small: 660,
    medium: 940,
    large: 1308
  },
  grid: 4,
  touchableSize: 12,
  space: {
    gutter: 6,
    xxsmall: 1,
    xsmall: 2,
    small: 3,
    medium: 5,
    large: 8,
    xlarge: 11,
    xxlarge: 15,
    xxxlarge: 20
  },
  transforms: {
    touchable: "scale(0.97)"
  },
  transitions: {
    fast: "transform .125s ease, opacity .125s ease",
    touchable: "transform 0.2s cubic-bezier(0.02, 1.505, 0.745, 1.235)"
  },
  border: {
    radius: {
      small: "4px",
      standard: "6px",
      large: "8px",
      xlarge: "12px"
    },
    width: {
      standard: 1,
      large: 2
    },
    color: {
      brandAccent,
      brandAccentLight: lib_color_palette_cjs.palette.grey["200"],
      caution: lib_color_palette_cjs.palette.yellow["600"],
      cautionLight: lib_color_palette_cjs.palette.yellow["300"],
      critical: lib_color_palette_cjs.palette.red["600"],
      criticalLight: lib_color_palette_cjs.palette.red["400"],
      field: lib_color_palette_cjs.palette.grey["400"],
      focus,
      formAccent,
      formAccentLight: lib_color_palette_cjs.palette.indigo["400"],
      info: lib_color_palette_cjs.palette.blue["600"],
      infoLight: lib_color_palette_cjs.palette.blue["400"],
      neutral: black,
      neutralInverted: lib_color_palette_cjs.palette.grey["100"],
      neutralLight: lib_color_palette_cjs.palette.grey["200"],
      positive: lib_color_palette_cjs.palette.mint["600"],
      positiveLight: lib_color_palette_cjs.palette.mint["400"],
      promote: lib_color_palette_cjs.palette.violet["600"],
      promoteLight: lib_color_palette_cjs.palette.violet["400"]
    }
  },
  focusRingSize: 3,
  shadows: {
    small: "0 2px 4px 0px rgba(28,28,28,.1), 0 2px 2px -2px rgba(28,28,28,.1), 0 4px 4px -4px rgba(28,28,28,.2)",
    medium: "0 2px 4px 0px rgba(28,28,28,.1), 0 8px 8px -4px rgba(28,28,28,.1), 0 12px 12px -8px rgba(28,28,28,.2)",
    large: "0 2px 4px 0px rgba(28,28,28,.1), 0 12px 12px -4px rgba(28,28,28,.1), 0 20px 20px -12px rgba(28,28,28,.2)"
  },
  color: {
    foreground: {
      brandAccent,
      brandAccentLight: lib_color_palette_cjs.palette.grey["200"],
      caution: lib_color_palette_cjs.palette.yellow["900"],
      cautionLight: lib_color_palette_cjs.palette.yellow["300"],
      critical: lib_color_palette_cjs.palette.red["700"],
      criticalLight: lib_color_palette_cjs.palette.red["400"],
      formAccent,
      formAccentLight: lib_color_palette_cjs.palette.indigo["400"],
      info: lib_color_palette_cjs.palette.blue["700"],
      infoLight: lib_color_palette_cjs.palette.blue["400"],
      link,
      linkHover: link,
      linkLight: lib_color_palette_cjs.palette.indigo["300"],
      linkVisited,
      linkLightVisited: linkVisited,
      neutral: black,
      neutralInverted: lib_color_palette_cjs.palette.grey["100"],
      positive: lib_color_palette_cjs.palette.mint["700"],
      positiveLight: lib_color_palette_cjs.palette.mint["400"],
      promote: lib_color_palette_cjs.palette.violet["700"],
      promoteLight: lib_color_palette_cjs.palette.violet["400"],
      rating: black,
      secondary,
      secondaryInverted: polished.rgba("#fff", 0.65)
    },
    background: {
      body: white,
      bodyDark: polished.darken(0.04, lib_color_palette_cjs.palette.grey["900"]),
      brand: lib_color_palette_cjs.palette.grey["900"],
      brandAccent,
      brandAccentActive: brandAccent,
      brandAccentHover: lib_color_palette_cjs.palette.grey["700"],
      brandAccentSoft: lib_color_palette_cjs.palette.grey["100"],
      brandAccentSoftActive: polished.darken(0.025, lib_color_palette_cjs.palette.grey["100"]),
      brandAccentSoftHover: polished.darken(0.05, lib_color_palette_cjs.palette.grey["100"]),
      caution: lib_color_palette_cjs.palette.yellow["500"],
      cautionLight: lib_color_palette_cjs.palette.yellow["100"],
      critical: lib_color_palette_cjs.palette.red["600"],
      criticalActive: polished.darken(0.075, lib_color_palette_cjs.palette.red["600"]),
      criticalHover: polished.darken(0.05, lib_color_palette_cjs.palette.red["600"]),
      criticalLight: lib_color_palette_cjs.palette.red["100"],
      criticalSoft: lib_color_palette_cjs.palette.red["100"],
      criticalSoftActive: polished.darken(0.05, lib_color_palette_cjs.palette.red["100"]),
      criticalSoftHover: polished.darken(0.025, lib_color_palette_cjs.palette.red["100"]),
      formAccent,
      formAccentActive: lib_color_palette_cjs.palette.indigo["700"],
      formAccentHover: polished.darken(0.05, lib_color_palette_cjs.palette.indigo["600"]),
      formAccentSoft: lib_color_palette_cjs.palette.indigo["50"],
      formAccentSoftActive: polished.darken(0.05, lib_color_palette_cjs.palette.indigo["50"]),
      formAccentSoftHover: polished.darken(0.025, lib_color_palette_cjs.palette.indigo["50"]),
      info: lib_color_palette_cjs.palette.blue["600"],
      infoLight: lib_color_palette_cjs.palette.blue["100"],
      neutral: lib_color_palette_cjs.palette.grey["800"],
      neutralActive: polished.darken(0.05, lib_color_palette_cjs.palette.grey["800"]),
      neutralHover: polished.lighten(0.05, lib_color_palette_cjs.palette.grey["800"]),
      neutralLight: lib_color_palette_cjs.palette.grey["100"],
      neutralSoft: lib_color_palette_cjs.palette.grey["50"],
      neutralSoftActive: polished.darken(0.05, lib_color_palette_cjs.palette.grey["50"]),
      neutralSoftHover: polished.darken(0.025, lib_color_palette_cjs.palette.grey["50"]),
      positive: lib_color_palette_cjs.palette.mint["700"],
      positiveLight: lib_color_palette_cjs.palette.mint["100"],
      promote: lib_color_palette_cjs.palette.violet["600"],
      promoteLight: lib_color_palette_cjs.palette.violet["100"],
      surface: white,
      surfaceDark: lib_color_palette_cjs.palette.grey["900"]
    }
  }
};
const tokens$1 = tokens;
exports.tokens = tokens$1;
